""" Fibonacci numbers as infinite generator function """

def fibonacci():
    old, new = 0, 1
    yield old
    yield new
    while True:
        old, new = new, old + new
        yield new

if __name__ == '__main__':
    """ how to chop a chunk of size 8? """

    # initialize the (infinite) generator
    gen = fibonacci()

    chunk_size = 8

    # 1. approach: a generator function
    def firstn(gen, n):
        """ a generic generator slice function """
        for i in range(n):
            yield next(gen)

    gen2 = firstn(gen, chunk_size)
    print('generator function', list(gen2))

    # 2. approach: a generator expression
    gen3 = (next(gen) for i in range(chunk_size))
    print('generator expression', list(gen3))

    # 3. approach: generate a list directly
    print('list', [next(gen) for i in range(chunk_size)])

    # 4. approach: use islice
    import itertools
    slc = itertools.islice(gen, chunk_size)
    print('itertools.islice', list(slc))
